=== modified file 'bzrlib/diff.py'
--- bzrlib/diff.py	2012-07-09 14:37:26 +0000
+++ bzrlib/diff.py	2012-07-12 15:59:35 +0000
@@ -427,7 +427,7 @@
                     path_encoding='utf8',
                     using=None,
                     format_cls=None,
-                    context):
+                    context=3):
     """Show in text form the changes from one tree to another.
 
     :param to_file: The output stream.
@@ -619,9 +619,9 @@
     # or removed in a diff.
     EPOCH_DATE = '1970-01-01 00:00:00 +0000'
 
-    def __init__(self, old_tree, new_tree, to_file, path_encoding='utf-8',
-                 old_label='', new_label='', text_differ=internal_diff,
-                 context_lines):
+    def __init__(self, old_tree, new_tree, to_file, path_encoding='utf-8', 
+                 old_label='', new_label='', text_differ=internal_diff, 
+                 context_lines=3):
         DiffPath.__init__(self, old_tree, new_tree, to_file, path_encoding)
         self.text_differ = text_differ
         self.old_label = old_label
@@ -933,7 +933,7 @@
             extra_factories = []
         if external_diff_options:
             opts = external_diff_options.split()
-            def diff_file(olab, olines, nlab, nlines, to_file, path_encoding=None):
+            def diff_file(olab, olines, nlab, nlines, to_file, path_encoding=None, context_lines=None):
                 """:param path_encoding: not used but required
                         to match the signature of internal_diff.
                 """

=== modified file 'bzrlib/tests/test_diff.py'
--- bzrlib/tests/test_diff.py	2012-01-25 21:13:15 +0000
+++ bzrlib/tests/test_diff.py	2012-07-12 15:59:35 +0000
@@ -211,6 +211,69 @@
         self.assertIsInstance(output.getvalue(), str,
             'internal_diff should return bytestrings')
 
+    def test_internal_diff_default_context(self):
+        output = StringIO()
+        diff.internal_diff('old', ['same_text\n','same_text\n','same_text\n',
+                           'same_text\n','same_text\n','old_text\n'],
+                           'new', ['same_text\n','same_text\n','same_text\n',
+                           'same_text\n','same_text\n','new_text\n'], output)
+        lines = output.getvalue().splitlines(True)
+        self.check_patch(lines)
+        self.assertEquals(['--- old\n',
+                           '+++ new\n',
+                           '@@ -3,4 +3,4 @@\n',
+                           ' same_text\n',
+                           ' same_text\n',
+                           ' same_text\n',
+                           '-old_text\n',
+                           '+new_text\n',
+                           '\n',
+                          ]
+                          , lines)
+
+    def test_internal_diff_no_context(self):
+        output = StringIO()
+        diff.internal_diff('old', ['same_text\n','same_text\n','same_text\n',
+                           'same_text\n','same_text\n','old_text\n'],
+                           'new', ['same_text\n','same_text\n','same_text\n',
+                           'same_text\n','same_text\n','new_text\n'], output,
+                           context_lines=0)
+        lines = output.getvalue().splitlines(True)
+        self.check_patch(lines)
+        self.assertEquals(['--- old\n',
+                           '+++ new\n',
+                           '@@ -6,1 +6,1 @@\n',
+                           '-old_text\n',
+                           '+new_text\n',
+                           '\n',
+                          ]
+                          , lines)
+
+    def test_internal_diff_more_context(self):
+        output = StringIO()
+        diff.internal_diff('old', ['same_text\n','same_text\n','same_text\n',
+                           'same_text\n','same_text\n','old_text\n'],
+                           'new', ['same_text\n','same_text\n','same_text\n',
+                           'same_text\n','same_text\n','new_text\n'], output,
+                           context_lines=4)
+        lines = output.getvalue().splitlines(True)
+        self.check_patch(lines)
+        self.assertEquals(['--- old\n',
+                           '+++ new\n',
+                           '@@ -2,5 +2,5 @@\n',
+                           ' same_text\n',
+                           ' same_text\n',
+                           ' same_text\n',
+                           ' same_text\n',
+                           '-old_text\n',
+                           '+new_text\n',
+                           '\n',
+                          ]
+                          , lines)
+
+
+
+
 
 class TestDiffFiles(tests.TestCaseInTempDir):
 

